// Example of a custom key handler that checks an
// host's actual CPU count against what's stated in
// a custom key, for Solaris-SPARC.  Pass an instance of
// this as the custom key handler into the 
// EzLicenseInfo.checkLicenseKey API call.
// At the time of key generation, set the custom key
// to the customer's stated CPU count as reported
// by the shell command "psrinfo".
// Note: this mechanism isn't designed to protect you from
// spoofing by a determined rogue programmer, who can quite easily
// create a fake "psrinfo" program that spews
// out a CPU count of 1.
// Note further that this code is not platform independent,
// which is why it is available as sample code and not an
// integral part of the (100 % Pure Java) product.

import com.vs.ezlicrun.*;
import java.util.*;
import java.io.*;
import java.text.*;

public class SolarisCpuCountHandler implements EzLicCustomLicenseInterface {
	
	public int checkCustomKeyCode(String valStr, Object ctx) 
			throws EzLicExceptionBase
	{
		int cpuCount = 0;
		int keyCpuCount = 0;
		String errMsg = null;
		try {
			BufferedReader rdr =
				new BufferedReader(
					new InputStreamReader(
						Runtime.getRuntime().exec("psrinfo | wc -l").getInputStream()));
			String line = null;
			if ((line = rdr.readLine()) != null) {
				line = line.trim();
				try {
					cpuCount = Integer.parseInt(line);
					keyCpuCount = Integer.parseInt(valStr);
				} catch (Throwable t) {
					cpuCount = 0;
					errMsg = "Exception: " +
						t.getClass().getName() +
						", Message: " + t.getMessage() +
						", shell cmd output: " +
						line;
				}
			}
			if (cpuCount <= 0 || cpuCount > 256)
				throw new Exception("Got strange CPU count of " + cpuCount);
		} catch (Exception eek) {
			EzLicExceptionBase.throwLicenseException(
					EzLicExceptionBase.EZLIC_EXC_INTERNAL,
						"Got unexpected exception: " +
						eek.getMessage());
		}
		if (cpuCount > keyCpuCount)
			EzLicExceptionBase.throwLicenseException(
				EzLicExceptionBase.EZLIC_EXC_INVALID_HOST_USER_NET, 
				"Too many CPU's: " + cpuCount);
		return 0; // return success with no warnings
	}
}
